
# This file was generated by 'versioneer.py' (0.18) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2024-09-24T13:33:13-0700",
 "dirty": false,
 "error": null,
 "full-revisionid": "813787d2f02f62cf4044caab08fa8b6eb4e0baec",
 "version": "2024.9.24"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
